@@ -19,7 +19,9 @@
  ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "config.h"
+#if defined(HAVE_SYS_AUXV_H)
 #include <sys/auxv.h>
+#endif
 #include <stdlib.h>
 #include <stdio.h>
 #include <getopt.h>
@@ -108,7 +110,7 @@ static H_PTR handle = NULL;
  * Local prototypes
  */
 #ifndef NO_DAEMON
-static H_UINT poolSize = 0;
+static int poolSize = 0;
 
 static void daemonize(void);
 static int  get_poolsize(void);
@@ -135,8 +137,10 @@ int main(int argc, char **argv)
 {
    volatile char *path = strdup(argv[0]);
    volatile char *arg0 = argv[0];
+#if defined(HAVE_SYS_AUXV_H)
    if (path[0] != '/')
       path = (char*)getauxval(AT_EXECFN);
+#endif
    static const char* cmds[] = {
       "b", "buffer",      "1", SETTINGR("Buffer size [KW], default: ",COLLECT_BUFSIZE),
       "d", "data",        "1", SETTINGR("Data cache size [KB], with fallback to: ", GENERIC_DCACHE ),
@@ -190,7 +194,9 @@ int main(int argc, char **argv)
    params->setup |= MULTI_CORE;
 #endif
 
-   first_byte = arg0[0];       
+#ifndef NO_COMMAND_MODE
+   first_byte = arg0[0];
+#endif
    if (access("/etc/initrd-release", F_OK) >= 0) {
       arg0[0] = '@';
       path[0] = '/';
@@ -686,7 +692,7 @@ static void run_daemon(    /* RETURN: nothing   */
          if (conn_fd >= 0)
             continue;
          }
-  
+
       if (conn_fd >= 0 && FD_ISSET(conn_fd, &read_fd))
          conn_fd = socket_handler(conn_fd, path, argv, params);
 #endif
@@ -717,7 +723,7 @@ static void set_watermark( /* RETURN: nothing   */
 {
    FILE *wm_fh;
 
-   if ( (H_UINT) level > (poolSize - 32))
+   if ( level > (poolSize - 32))
       level = poolSize - 32;
    wm_fh = fopen(params->watermark, "w");
    if (wm_fh) {
@@ -738,7 +744,7 @@ static void anchor_info(H_PTR h)
    char       buf[120];
    H_SD_TOPIC topics[4] = {H_SD_TOPIC_BUILD, H_SD_TOPIC_TUNE, H_SD_TOPIC_TEST, H_SD_TOPIC_SUM};
    int        i;
-   
+
    for(i=0;i<4;i++)
       if (havege_status_dump(h, topics[i], buf, sizeof(buf))>0)
          print_msg("%s\n", buf);
